==> systemds-3.2.0-src.zip: systemds-3.2.0-src/src/test/java/org/apache/sysds/performance/simple/NNZ.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.sysds.performance.simple;

import org.apache.sysds.runtime.controlprogram.parfor.stat.Timing;
import org.apache.sysds.runtime.matrix.data.MatrixBlock;
import org.apache.sysds.test.TestUtils;

public class NNZ {
	public static void main(String[] args) {
		MatrixBlock mb = TestUtils.generateTestMatrixBlock(10000, 1000, 0, 103, 0.7, 421);
		Timing t = new Timing();
		t.start();
		for(int i = 0; i < 1000; i++) {
			mb.recomputeNonZeros();
		}
		System.out.println("single:   " + t.stop() / 1000);
		t.start();
		for(int i = 0; i < 1000; i++) {

			mb.recomputeNonZeros(16);
		}

		System.out.println("par:      " + t.stop() / 1000);
		t.start();
		for(int i = 0; i < 1000; i++) {
			mb.recomputeNonZeros();
		}
		System.out.println("single:   " + t.stop() / 1000);
		t.start();
		for(int i = 0; i < 1000; i++) {

			mb.recomputeNonZeros(16);
		}

		System.out.println("par:      " + t.stop() / 1000);
	}
}

==> systemds-3.3.0-src.zip: systemds-3.3.0-src/src/test/java/org/apache/sysds/performance/simple/NNZ.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.sysds.performance.simple;

import org.apache.sysds.runtime.matrix.data.MatrixBlock;
import org.apache.sysds.test.TestUtils;
import org.apache.sysds.utils.stats.Timing;

public class NNZ {
	public static void main(String[] args) {
		MatrixBlock mb = TestUtils.generateTestMatrixBlock(10000, 1000, 0, 103, 0.7, 421);
		Timing t = new Timing();
		t.start();
		for(int i = 0; i < 1000; i++) {
			mb.recomputeNonZeros();
		}
		System.out.println("single:   " + t.stop() / 1000);
		t.start();
		for(int i = 0; i < 1000; i++) {

			mb.recomputeNonZeros(16);
		}

		System.out.println("par:      " + t.stop() / 1000);
		t.start();
		for(int i = 0; i < 1000; i++) {
			mb.recomputeNonZeros();
		}
		System.out.println("single:   " + t.stop() / 1000);
		t.start();
		for(int i = 0; i < 1000; i++) {

			mb.recomputeNonZeros(16);
		}

		System.out.println("par:      " + t.stop() / 1000);
	}
}
